/****************************************************************************
**
** Copyright (C) 2022 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  hal_ll_analog_in_map.h
 * @brief Macros used for setting pin analog functionality.
 */

#ifndef _HAL_LL_ANALOG_IN_MAP_H_
#define _HAL_LL_ANALOG_IN_MAP_H_

#ifdef __cplusplus
extern "C"{
#endif

#include "hal_ll_pin_names.h"

typedef struct
{
    uint8_t pin;
    uint8_t module_index;
    uint8_t channel;
    uint8_t analog_in_register_bit;
    uint16_t analog_in_register_addr;
    bool multiple_pcfg_sel;
} hal_ll_pin_channel_list_t;

static const hal_ll_pin_channel_list_t hal_ll_analog_in_register_list[HAL_LL_AN_COUNT + 1] =
{
    //------------ BEGIN
    #ifdef HAL_LL_RB0_AN12_ADCON1
    { PB0, 0, HAL_LL_RB0_AN12_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB4_AN11_ADCON1
    { PB4, 0, HAL_LL_RB4_AN11_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB1_AN10_ADCON1
    { PB1, 0, HAL_LL_RB1_AN10_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB2_AN8_ADCON1
    { PB2, 0, HAL_LL_RB2_AN8_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB3_AN9_ADCON1
    { PB3, 0, HAL_LL_RB3_AN9_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RA3_AN3_ADCON1
    { PA3, 0, HAL_LL_RA3_AN3_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RA5_AN4_ADCON1
    { PA5, 0, HAL_LL_RA5_AN4_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RA2_AN2_ADCON1
    { PA2, 0, HAL_LL_RA2_AN2_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RA0_AN0_ADCON1
    { PA0, 0, HAL_LL_RA0_AN0_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RA1_AN1_ADCON1
    { PA1, 0, HAL_LL_RA1_AN1_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB0_AN12_ANCON1
    { PB0, 0, HAL_LL_RB0_AN12_ANCON1, HAL_LL_RB0_AN12_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB1_AN10_ANCON1
    { PB1, 0, HAL_LL_RB1_AN10_ANCON1, HAL_LL_RB1_AN10_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB2_AN8_ANCON1
    { PB2, 0, HAL_LL_RB2_AN8_ANCON1, HAL_LL_RB2_AN8_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB3_AN9_ANCON1
    { PB3, 0, HAL_LL_RB3_AN9_ANCON1, HAL_LL_RB3_AN9_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA3_AN3_ANCON0
    { PA3, 0, HAL_LL_RA3_AN3_ANCON0, HAL_LL_RA3_AN3_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA5_AN4_ANCON0
    { PA5, 0, HAL_LL_RA5_AN4_ANCON0, HAL_LL_RA5_AN4_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA2_AN2_ANCON0
    { PA2, 0, HAL_LL_RA2_AN2_ANCON0, HAL_LL_RA2_AN2_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA0_AN0_ANCON0
    { PA0, 0, HAL_LL_RA0_AN0_ANCON0, HAL_LL_RA0_AN0_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA1_AN1_ANCON0
    { PA1, 0, HAL_LL_RA1_AN1_ANCON0, HAL_LL_RA1_AN1_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC2_AN11_ANCON1
    { PC2, 0, HAL_LL_RC2_AN11_ANCON1, HAL_LL_RC2_AN11_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB0_AN12_ANSELB
    { PB0, 0, HAL_LL_RB0_AN12_ANSELB, HAL_LL_RB0_AN12_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC7_AN19_ANSELC
    { PC7, 0, HAL_LL_RC7_AN19_ANSELC, HAL_LL_RC7_AN19_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC6_AN18_ANSELC
    { PC6, 0, HAL_LL_RC6_AN18_ANSELC, HAL_LL_RC6_AN18_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB5_AN13_ANSELB
    { PB5, 0, HAL_LL_RB5_AN13_ANSELB, HAL_LL_RB5_AN13_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB4_AN11_ANSELB
    { PB4, 0, HAL_LL_RB4_AN11_ANSELB, HAL_LL_RB4_AN11_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB1_AN10_ANSELB
    { PB1, 0, HAL_LL_RB1_AN10_ANSELB, HAL_LL_RB1_AN10_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB2_AN8_ANSELB
    { PB2, 0, HAL_LL_RB2_AN8_ANSELB, HAL_LL_RB2_AN8_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB3_AN9_ANSELB
    { PB3, 0, HAL_LL_RB3_AN9_ANSELB, HAL_LL_RB3_AN9_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA3_AN3_ANSELA
    { PA3, 0, HAL_LL_RA3_AN3_ANSELA, HAL_LL_RA3_AN3_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA5_AN4_ANSELA
    { PA5, 0, HAL_LL_RA5_AN4_ANSELA, HAL_LL_RA5_AN4_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA2_AN2_ANSELA
    { PA2, 0, HAL_LL_RA2_AN2_ANSELA, HAL_LL_RA2_AN2_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA0_AN0_ANSELA
    { PA0, 0, HAL_LL_RA0_AN0_ANSELA, HAL_LL_RA0_AN0_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA1_AN1_ANSELA
    { PA1, 0, HAL_LL_RA1_AN1_ANSELA, HAL_LL_RA1_AN1_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC2_AN14_ANSELC
    { PC2, 0, HAL_LL_RC2_AN14_ANSELC, HAL_LL_RC2_AN14_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB0_AN10_ADCON1
    { PB0, 0, HAL_LL_RB0_AN10_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB4_AN9_ADCON1
    { PB4, 0, HAL_LL_RB4_AN9_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB1_AN8_ADCON1
    { PB1, 0, HAL_LL_RB1_AN8_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RB0_ANB0_ANSELB
    { PB0, 0, HAL_LL_RB0_ANB0_ANSELB, HAL_LL_RB0_ANB0_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC7_ANC7_ANSELC
    { PC7, 0, HAL_LL_RC7_ANC7_ANSELC, HAL_LL_RC7_ANC7_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC4_ANC4_ANSELC
    { PC4, 0, HAL_LL_RC4_ANC4_ANSELC, HAL_LL_RC4_ANC4_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC5_ANC5_ANSELC
    { PC5, 0, HAL_LL_RC5_ANC5_ANSELC, HAL_LL_RC5_ANC5_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC6_ANC6_ANSELC
    { PC6, 0, HAL_LL_RC6_ANC6_ANSELC, HAL_LL_RC6_ANC6_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB5_ANB5_ANSELB
    { PB5, 0, HAL_LL_RB5_ANB5_ANSELB, HAL_LL_RB5_ANB5_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB6_ANB6_ANSELB
    { PB6, 0, HAL_LL_RB6_ANB6_ANSELB, HAL_LL_RB6_ANB6_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB7_ANB7_ANSELB
    { PB7, 0, HAL_LL_RB7_ANB7_ANSELB, HAL_LL_RB7_ANB7_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB4_ANB4_ANSELB
    { PB4, 0, HAL_LL_RB4_ANB4_ANSELB, HAL_LL_RB4_ANB4_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB1_ANB1_ANSELB
    { PB1, 0, HAL_LL_RB1_ANB1_ANSELB, HAL_LL_RB1_ANB1_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB2_ANB2_ANSELB
    { PB2, 0, HAL_LL_RB2_ANB2_ANSELB, HAL_LL_RB2_ANB2_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB3_ANB3_ANSELB
    { PB3, 0, HAL_LL_RB3_ANB3_ANSELB, HAL_LL_RB3_ANB3_ANSELB_BIT, HAL_LL_ANSELB_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA3_ANA3_ANSELA
    { PA3, 0, HAL_LL_RA3_ANA3_ANSELA, HAL_LL_RA3_ANA3_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA4_ANA4_ANSELA
    { PA4, 0, HAL_LL_RA4_ANA4_ANSELA, HAL_LL_RA4_ANA4_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA5_ANA5_ANSELA
    { PA5, 0, HAL_LL_RA5_ANA5_ANSELA, HAL_LL_RA5_ANA5_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA2_ANA2_ANSELA
    { PA2, 0, HAL_LL_RA2_ANA2_ANSELA, HAL_LL_RA2_ANA2_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA0_ANA0_ANSELA
    { PA0, 0, HAL_LL_RA0_ANA0_ANSELA, HAL_LL_RA0_ANA0_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA1_ANA1_ANSELA
    { PA1, 0, HAL_LL_RA1_ANA1_ANSELA, HAL_LL_RA1_ANA1_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC1_ANC1_ANSELC
    { PC1, 0, HAL_LL_RC1_ANC1_ANSELC, HAL_LL_RC1_ANC1_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC2_ANC2_ANSELC
    { PC2, 0, HAL_LL_RC2_ANC2_ANSELC, HAL_LL_RC2_ANC2_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC3_ANC3_ANSELC
    { PC3, 0, HAL_LL_RC3_ANC3_ANSELC, HAL_LL_RC3_ANC3_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC0_ANC0_ANSELC
    { PC0, 0, HAL_LL_RC0_ANC0_ANSELC, HAL_LL_RC0_ANC0_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA7_ANA7_ANSELA
    { PA7, 0, HAL_LL_RA7_ANA7_ANSELA, HAL_LL_RA7_ANA7_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA6_ANA6_ANSELA
    { PA6, 0, HAL_LL_RA6_ANA6_ANSELA, HAL_LL_RA6_ANA6_ANSELA_BIT, HAL_LL_ANSELA_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB0_AN10_ANCON1
    { PB0, 0, HAL_LL_RB0_AN10_ANCON1, HAL_LL_RB0_AN10_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB4_AN9_ANCON1
    { PB4, 0, HAL_LL_RB4_AN9_ANCON1, HAL_LL_RB4_AN9_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB1_AN8_ANCON1
    { PB1, 0, HAL_LL_RB1_AN8_ANCON1, HAL_LL_RB1_AN8_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB0_AN12_ANSELH
    { PB0, 0, HAL_LL_RB0_AN12_ANSELH, HAL_LL_RB0_AN12_ANSELH_BIT, HAL_LL_ANSELH_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB4_AN11_ANSELH
    { PB4, 0, HAL_LL_RB4_AN11_ANSELH, HAL_LL_RB4_AN11_ANSELH_BIT, HAL_LL_ANSELH_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB1_AN10_ANSELH
    { PB1, 0, HAL_LL_RB1_AN10_ANSELH, HAL_LL_RB1_AN10_ANSELH_BIT, HAL_LL_ANSELH_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB2_AN8_ANSELH
    { PB2, 0, HAL_LL_RB2_AN8_ANSELH, HAL_LL_RB2_AN8_ANSELH_BIT, HAL_LL_ANSELH_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RB3_AN9_ANSELH
    { PB3, 0, HAL_LL_RB3_AN9_ANSELH, HAL_LL_RB3_AN9_ANSELH_BIT, HAL_LL_ANSELH_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA3_AN3_ANSEL
    { PA3, 0, HAL_LL_RA3_AN3_ANSEL, HAL_LL_RA3_AN3_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA5_AN4_ANSEL
    { PA5, 0, HAL_LL_RA5_AN4_ANSEL, HAL_LL_RA5_AN4_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA2_AN2_ANSEL
    { PA2, 0, HAL_LL_RA2_AN2_ANSEL, HAL_LL_RA2_AN2_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA0_AN0_ANSEL
    { PA0, 0, HAL_LL_RA0_AN0_ANSEL, HAL_LL_RA0_AN0_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA1_AN1_ANSEL
    { PA1, 0, HAL_LL_RA1_AN1_ANSEL, HAL_LL_RA1_AN1_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC4_AN16_ANSELC
    { PC4, 0, HAL_LL_RC4_AN16_ANSELC, HAL_LL_RC4_AN16_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC5_AN17_ANSELC
    { PC5, 0, HAL_LL_RC5_AN17_ANSELC, HAL_LL_RC5_AN17_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC3_AN15_ANSELC
    { PC3, 0, HAL_LL_RC3_AN15_ANSELC, HAL_LL_RC3_AN15_ANSELC_BIT, HAL_LL_ANSELC_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE0_AN5_ADCON1
    { PE0, 0, HAL_LL_RE0_AN5_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RE2_AN7_ADCON1
    { PE2, 0, HAL_LL_RE2_AN7_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RE1_AN6_ADCON1
    { PE1, 0, HAL_LL_RE1_AN6_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RE0_AN5_ANCON0
    { PE0, 0, HAL_LL_RE0_AN5_ANCON0, HAL_LL_RE0_AN5_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE1_AN6_ANCON0
    { PE1, 0, HAL_LL_RE1_AN6_ANCON0, HAL_LL_RE1_AN6_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE2_AN7_ANCON0
    { PE2, 0, HAL_LL_RE2_AN7_ANCON0, HAL_LL_RE2_AN7_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD4_AND4_ANSELD
    { PD4, 0, HAL_LL_RD4_AND4_ANSELD, HAL_LL_RD4_AND4_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD5_AND5_ANSELD
    { PD5, 0, HAL_LL_RD5_AND5_ANSELD, HAL_LL_RD5_AND5_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD7_AND7_ANSELD
    { PD7, 0, HAL_LL_RD7_AND7_ANSELD, HAL_LL_RD7_AND7_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD6_AND6_ANSELD
    { PD6, 0, HAL_LL_RD6_AND6_ANSELD, HAL_LL_RD6_AND6_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD3_AND3_ANSELD
    { PD3, 0, HAL_LL_RD3_AND3_ANSELD, HAL_LL_RD3_AND3_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD2_AND2_ANSELD
    { PD2, 0, HAL_LL_RD2_AND2_ANSELD, HAL_LL_RD2_AND2_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE0_ANE0_ANSELE
    { PE0, 0, HAL_LL_RE0_ANE0_ANSELE, HAL_LL_RE0_ANE0_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE2_ANE2_ANSELE
    { PE2, 0, HAL_LL_RE2_ANE2_ANSELE, HAL_LL_RE2_ANE2_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE1_ANE1_ANSELE
    { PE1, 0, HAL_LL_RE1_ANE1_ANSELE, HAL_LL_RE1_ANE1_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD1_AND1_ANSELD
    { PD1, 0, HAL_LL_RD1_AND1_ANSELD, HAL_LL_RD1_AND1_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD0_AND0_ANSELD
    { PD0, 0, HAL_LL_RD0_AND0_ANSELD, HAL_LL_RD0_AND0_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD4_AN24_ANSELD
    { PD4, 0, HAL_LL_RD4_AN24_ANSELD, HAL_LL_RD4_AN24_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD5_AN25_ANSELD
    { PD5, 0, HAL_LL_RD5_AN25_ANSELD, HAL_LL_RD5_AN25_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD7_AN27_ANSELD
    { PD7, 0, HAL_LL_RD7_AN27_ANSELD, HAL_LL_RD7_AN27_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD6_AN26_ANSELD
    { PD6, 0, HAL_LL_RD6_AN26_ANSELD, HAL_LL_RD6_AN26_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD3_AN23_ANSELD
    { PD3, 0, HAL_LL_RD3_AN23_ANSELD, HAL_LL_RD3_AN23_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD2_AN22_ANSELD
    { PD2, 0, HAL_LL_RD2_AN22_ANSELD, HAL_LL_RD2_AN22_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE0_AN5_ANSELE
    { PE0, 0, HAL_LL_RE0_AN5_ANSELE, HAL_LL_RE0_AN5_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE2_AN7_ANSELE
    { PE2, 0, HAL_LL_RE2_AN7_ANSELE, HAL_LL_RE2_AN7_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE1_AN6_ANSELE
    { PE1, 0, HAL_LL_RE1_AN6_ANSELE, HAL_LL_RE1_AN6_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD1_AN21_ANSELD
    { PD1, 0, HAL_LL_RD1_AN21_ANSELD, HAL_LL_RD1_AN21_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RD0_AN20_ANSELD
    { PD0, 0, HAL_LL_RD0_AN20_ANSELD, HAL_LL_RD0_AN20_ANSELD_BIT, HAL_LL_ANSELD_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE0_AN5_ANSEL
    { PE0, 0, HAL_LL_RE0_AN5_ANSEL, HAL_LL_RE0_AN5_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE2_AN7_ANSEL
    { PE2, 0, HAL_LL_RE2_AN7_ANSEL, HAL_LL_RE2_AN7_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE1_AN6_ANSEL
    { PE1, 0, HAL_LL_RE1_AN6_ANSEL, HAL_LL_RE1_AN6_ANSEL_BIT, HAL_LL_ANSEL_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF7_ANF7_ANSELF
    { PF7, 0, HAL_LL_RF7_ANF7_ANSELF, HAL_LL_RF7_ANF7_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF6_ANF6_ANSELF
    { PF6, 0, HAL_LL_RF6_ANF6_ANSELF, HAL_LL_RF6_ANF6_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF2_ANF2_ANSELF
    { PF2, 0, HAL_LL_RF2_ANF2_ANSELF, HAL_LL_RF2_ANF2_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF1_ANF1_ANSELF
    { PF1, 0, HAL_LL_RF1_ANF1_ANSELF, HAL_LL_RF1_ANF1_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF0_ANF0_ANSELF
    { PF0, 0, HAL_LL_RF0_ANF0_ANSELF, HAL_LL_RF0_ANF0_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF5_ANF5_ANSELF
    { PF5, 0, HAL_LL_RF5_ANF5_ANSELF, HAL_LL_RF5_ANF5_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF4_ANF4_ANSELF
    { PF4, 0, HAL_LL_RF4_ANF4_ANSELF, HAL_LL_RF4_ANF4_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF3_ANF3_ANSELF
    { PF3, 0, HAL_LL_RF3_ANF3_ANSELF, HAL_LL_RF3_ANF3_ANSELF_BIT, HAL_LL_ANSELF_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF6_AN11_ADCON1
    { PF6, 0, HAL_LL_RF6_AN11_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF3_AN8_ADCON1
    { PF3, 0, HAL_LL_RF3_AN8_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF2_AN7_ADCON1
    { PF2, 0, HAL_LL_RF2_AN7_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF5_AN10_ADCON1
    { PF5, 0, HAL_LL_RF5_AN10_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF4_AN9_ADCON1
    { PF4, 0, HAL_LL_RF4_AN9_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF1_AN6_ADCON1
    { PF1, 0, HAL_LL_RF1_AN6_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF0_AN5_ADCON1
    { PF0, 0, HAL_LL_RF0_AN5_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF7_AN5_ADCON1
    { PF7, 0, HAL_LL_RF7_AN5_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RF6_AN11_ANCON1
    { PF6, 0, HAL_LL_RF6_AN11_ANCON1, HAL_LL_RF6_AN11_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF2_AN7_ANCON0
    { PF2, 0, HAL_LL_RF2_AN7_ANCON0, HAL_LL_RF2_AN7_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF5_AN10_ANCON1
    { PF5, 0, HAL_LL_RF5_AN10_ANCON1, HAL_LL_RF5_AN10_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RC2_AN9_ANCON2
    { PC2, 0, HAL_LL_RC2_AN9_ANCON2, HAL_LL_RC2_AN9_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF7_AN5_ANCON1
    { PF7, 0, HAL_LL_RF7_AN5_ANCON1, HAL_LL_RF7_AN5_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF6_AN11_ANCON2
    { PF6, 0, HAL_LL_RF6_AN11_ANCON2, HAL_LL_RF6_AN11_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF2_AN7_ANCON1
    { PF2, 0, HAL_LL_RF2_AN7_ANCON1, HAL_LL_RF2_AN7_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF5_AN10_ANCON2
    { PF5, 0, HAL_LL_RF5_AN10_ANCON2, HAL_LL_RF5_AN10_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG0_AN8_ANCON2
    { PG0, 0, HAL_LL_RG0_AN8_ANCON2, HAL_LL_RG0_AN8_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG1_AN19_ANCON3
    { PG1, 0, HAL_LL_RG1_AN19_ANCON3, HAL_LL_RG1_AN19_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG4_AN16_ANCON3
    { PG4, 0, HAL_LL_RG4_AN16_ANCON3, HAL_LL_RG4_AN16_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG2_AN18_ANCON3
    { PG2, 0, HAL_LL_RG2_AN18_ANCON3, HAL_LL_RG2_AN18_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG3_AN17_ANCON3
    { PG3, 0, HAL_LL_RG3_AN17_ANCON3, HAL_LL_RG3_AN17_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA5_AN4_ANCON1
    { PA5, 0, HAL_LL_RA5_AN4_ANCON1, HAL_LL_RA5_AN4_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA4_AN6_ANCON1
    { PA4, 0, HAL_LL_RA4_AN6_ANCON1, HAL_LL_RA4_AN6_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA1_AN1_ANCON1
    { PA1, 0, HAL_LL_RA1_AN1_ANCON1, HAL_LL_RA1_AN1_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA0_AN0_ANCON1
    { PA0, 0, HAL_LL_RA0_AN0_ANCON1, HAL_LL_RA0_AN0_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA3_AN3_ANCON1
    { PA3, 0, HAL_LL_RA3_AN3_ANCON1, HAL_LL_RA3_AN3_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RA2_AN2_ANCON1
    { PA2, 0, HAL_LL_RA2_AN2_ANCON1, HAL_LL_RA2_AN2_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF7_AN5_ANCON0
    { PF7, 0, HAL_LL_RF7_AN5_ANCON0, HAL_LL_RF7_AN5_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF3_AN8_ANCON1
    { PF3, 0, HAL_LL_RF3_AN8_ANCON1, HAL_LL_RF3_AN8_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF4_AN9_ANCON1
    { PF4, 0, HAL_LL_RF4_AN9_ANCON1, HAL_LL_RF4_AN9_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG1_AN19_ANCON2
    { PG1, 0, HAL_LL_RG1_AN19_ANCON2, HAL_LL_RG1_AN19_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG4_AN16_ANCON2
    { PG4, 0, HAL_LL_RG4_AN16_ANCON2, HAL_LL_RG4_AN16_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG2_AN18_ANCON2
    { PG2, 0, HAL_LL_RG2_AN18_ANCON2, HAL_LL_RG2_AN18_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG3_AN17_ANCON2
    { PG3, 0, HAL_LL_RG3_AN17_ANCON2, HAL_LL_RG3_AN17_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RF1_AN6_ANCON0
    { PF1, 0, HAL_LL_RF1_AN6_ANCON0, HAL_LL_RF1_AN6_ANCON0_BIT, HAL_LL_ANCON0_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE7_ANE7_ANSELE
    { PE7, 0, HAL_LL_RE7_ANE7_ANSELE, HAL_LL_RE7_ANE7_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE6_ANE6_ANSELE
    { PE6, 0, HAL_LL_RE6_ANE6_ANSELE, HAL_LL_RE6_ANE6_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE3_ANE3_ANSELE
    { PE3, 0, HAL_LL_RE3_ANE3_ANSELE, HAL_LL_RE3_ANE3_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE5_ANE5_ANSELE
    { PE5, 0, HAL_LL_RE5_ANE5_ANSELE, HAL_LL_RE5_ANE5_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RE4_ANE4_ANSELE
    { PE4, 0, HAL_LL_RE4_ANE4_ANSELE, HAL_LL_RE4_ANE4_ANSELE_BIT, HAL_LL_ANSELE_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG0_ANG0_ANSELG
    { PG0, 0, HAL_LL_RG0_ANG0_ANSELG, HAL_LL_RG0_ANG0_ANSELG_BIT, HAL_LL_ANSELG_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG1_ANG1_ANSELG
    { PG1, 0, HAL_LL_RG1_ANG1_ANSELG, HAL_LL_RG1_ANG1_ANSELG_BIT, HAL_LL_ANSELG_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG4_ANG4_ANSELG
    { PG4, 0, HAL_LL_RG4_ANG4_ANSELG, HAL_LL_RG4_ANG4_ANSELG_BIT, HAL_LL_ANSELG_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG2_ANG2_ANSELG
    { PG2, 0, HAL_LL_RG2_ANG2_ANSELG, HAL_LL_RG2_ANG2_ANSELG_BIT, HAL_LL_ANSELG_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG3_ANG3_ANSELG
    { PG3, 0, HAL_LL_RG3_ANG3_ANSELG, HAL_LL_RG3_ANG3_ANSELG_BIT, HAL_LL_ANSELG_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG7_ANG7_ANSELG
    { PG7, 0, HAL_LL_RG7_ANG7_ANSELG, HAL_LL_RG7_ANG7_ANSELG_BIT, HAL_LL_ANSELG_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RG6_ANG6_ANSELG
    { PG6, 0, HAL_LL_RG6_ANG6_ANSELG, HAL_LL_RG6_ANG6_ANSELG_BIT, HAL_LL_ANSELG_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH7_AN15_ADCON1
    { PH7, 0, HAL_LL_RH7_AN15_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RH6_AN14_ADCON1
    { PH6, 0, HAL_LL_RH6_AN14_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RH5_AN13_ADCON1
    { PH5, 0, HAL_LL_RH5_AN13_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RH4_AN12_ADCON1
    { PH4, 0, HAL_LL_RH4_AN12_ADCON1, 0, HAL_LL_ADCON1_ADDRESS, true },
    #endif
    #ifdef HAL_LL_RH7_AN15_ANCON1
    { PH7, 0, HAL_LL_RH7_AN15_ANCON1, HAL_LL_RH7_AN15_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH6_AN14_ANCON1
    { PH6, 0, HAL_LL_RH6_AN14_ANCON1, HAL_LL_RH6_AN14_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH5_AN13_ANCON1
    { PH5, 0, HAL_LL_RH5_AN13_ANCON1, HAL_LL_RH5_AN13_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH4_AN12_ANCON1
    { PH4, 0, HAL_LL_RH4_AN12_ANCON1, HAL_LL_RH4_AN12_ANCON1_BIT, HAL_LL_ANCON1_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH0_AN23_ANCON3
    { PH0, 0, HAL_LL_RH0_AN23_ANCON3, HAL_LL_RH0_AN23_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH1_AN22_ANCON3
    { PH1, 0, HAL_LL_RH1_AN22_ANCON3, HAL_LL_RH1_AN22_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH7_AN15_ANCON2
    { PH7, 0, HAL_LL_RH7_AN15_ANCON2, HAL_LL_RH7_AN15_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH6_AN14_ANCON2
    { PH6, 0, HAL_LL_RH6_AN14_ANCON2, HAL_LL_RH6_AN14_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH2_AN21_ANCON3
    { PH2, 0, HAL_LL_RH2_AN21_ANCON3, HAL_LL_RH2_AN21_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH3_AN20_ANCON3
    { PH3, 0, HAL_LL_RH3_AN20_ANCON3, HAL_LL_RH3_AN20_ANCON3_BIT, HAL_LL_ANCON3_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH5_AN13_ANCON2
    { PH5, 0, HAL_LL_RH5_AN13_ANCON2, HAL_LL_RH5_AN13_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH4_AN12_ANCON2
    { PH4, 0, HAL_LL_RH4_AN12_ANCON2, HAL_LL_RH4_AN12_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH0_AN23_ANCON2
    { PH0, 0, HAL_LL_RH0_AN23_ANCON2, HAL_LL_RH0_AN23_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH1_AN22_ANCON2
    { PH1, 0, HAL_LL_RH1_AN22_ANCON2, HAL_LL_RH1_AN22_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH2_AN21_ANCON2
    { PH2, 0, HAL_LL_RH2_AN21_ANCON2, HAL_LL_RH2_AN21_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif
    #ifdef HAL_LL_RH3_AN20_ANCON2
    { PH3, 0, HAL_LL_RH3_AN20_ANCON2, HAL_LL_RH3_AN20_ANCON2_BIT, HAL_LL_ANCON2_ADDRESS, false },
    #endif

    { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, false }
    //------------ END
};

#ifdef __cplusplus
}
#endif

#endif // _HAL_LL_ANALOG_IN_MAP_H_
// ------------------------------------------------------------------------- END
