// simple UART test program - 64MHz internal oscillator
// uses SDK purely to get use of PIC18F47Q10 - then totally ignores everything SDK
// no libraries are availble with SDK, so I had to write all of my own functions from scratch

// Amateur code, use at own risk - author accepts no responsibility for anything, anywhere, ever
// Nothing clever here - just playing and learning. Code is messy and would benefit from major tidy-up

// connect terminal to RC6=Tx, RC7=Rx, 115200,8,n,1
// fit LCD and turn on back-light
// fit serial 7-seg display to port D (optional)

// turn on switches SW4 7 and 8 for easyPIC 7a on-board EEPROM
// .... or alternatively ....
// fit EEPROM click board to mikroBUS 1

// status 26 September 2022
//    - seems OK

// SPI 2 connections:
//     RD0 CS#
//     RD3 SCK
//     RD2 MISO
//     RD5 MOSI

// EP7a    mikroBUS 1 socket           mikroBUS 2 socket
//
//       AN   RA2      RC0 PWM       AN   RA3      RC1 PWM
//       RST  RE1      RB0 INT       RST  RE2      RB1 INT
//       CS   RE0      RC7 RX        CS   RA5      RC7 RX
//       SCK  RC3      RC6 TX        SCK  RC3      RC6 TX
//       MISO RC4      RC3 SCL       MISO RC4      RC3 SCL
//       MOSI RC5      RC4 SDA       MOSI RC5      RC4 SDA
//       +3.3              +5        +3.3              +5
//       GND               GND       GND               GND

// EEPROM Click with  24C08-WP fitted
//     nc     WP       write protect when high - take low if write wanted 
//     nc     nc
//     nc     nc
//     nc     nc
//     nc     SCL
//     nc     SDA
//  +3.3V     +5V      (not used if 3.3V selected)
//    Gnd     Gnd

// LCD connections
//
//  1  GND GND
//  2  VCC +5V
//  3   Vo contrast 3k3/1k voltage divider 5V
//  4   RS RB4
//  5  R/W GND
//  6    E RB5
//  7   D0 GND
//  8   D1 GND
//  9   D2 GND
// 10   D3 GND
// 11   D4 RB0
// 12   D5 RB1
// 13   D6 RB2
// 14   D7 RB3
// 15 LED+ A      Via SW6-3 BCKL from +5V
// 16 LED- K      Via SW6-4 PWM Driven by RC2

//  ***6***   bit numbering for 7 seg
//  *     *
//  1     5
//  *     *
//  ***0***
//  *     *
//  2     4
//  *     *
//  ***3***  7

// pin definitions
#define i2cEEPROM_WP LATC0_bit                                             // connect EEPROM to RC0 or to ground
// Serial 7-seg Display connections
sbit Chip_Select at LATD0_bit;
sbit Chip_Select_Direction at TRISD0_bit;

// function prototypes - for descriptions, see function code
void linein(char* pstring);
char getparams(char* tempstring);
void PrintHex(unsigned char ihex);
void PrintHexSp(unsigned char ihex);
void PrintHexInt(unsigned int ihex);
void cmd7(void);
void cmda(void);
void cmdd(void);
void cmdf(void);
void cmdl(void);
void cmdr(void);
void cmdt(void);
void cmdw(void);
void cmdz(void);
void I2C1_Init(unsigned long clock);
unsigned short I2C1_Start(void);
void I2C1_Repeated_Start(void);
void I2C1_Stop(void);
unsigned short I2C1_Wr(unsigned short data_);
unsigned char I2C1_Rd(unsigned char ackflag);
void i2cEEPROM_WrSingle(unsigned int wAddr, unsigned char wData);
unsigned char i2cEEPROM_RdSingle(unsigned int rAddr);
void LCD_Data4(unsigned char lcd_d);
void LCD_Cmd4(char lcmd);
void LCD_Init(void);                                                            // initialise EP8 2x16 LCD
void LCD_clear(void);
void LCD_Pos(unsigned char row, unsigned char col);
void LCD_Write(unsigned char lcd_byte);
void LCD_Text(char *ltxt);
void LCD_Cmd(unsigned char lcmd);
void SPI2_Init(void);
void max7219_init(void);
void set_luminosity(unsigned char value);
void display_column(unsigned char col, unsigned char col_num);

// global variables
unsigned long count10ms;                                                        // count tens of milliseconds
unsigned char newcmd;                                                           // save most recent command letter
char cmd;                                                                       // first letter of input line
char linebuff[257];                                                             // allow up to this many characters in input line
unsigned char param[8][20];                                                     // up to 8 parameters
unsigned int upar[8];                                                           // parameters as word
unsigned char nparams;                                                          // number of parameters
unsigned char EC_hdr;
unsigned char EC_tmp;
unsigned int EC_adr;                                                            // memory address
unsigned char EC_data;                                                          // memory data
unsigned int ee_addr;                                                           // EEPROM address
char ascii_string[18];                                                          // store ASCII string for "r" command
char sec, min1, hr, week_day, day, mn, year;                                    // store information read from 1307 RTC
char *txt, tnum[4];                                                             // buffers for 1307 RTC
unsigned char t_sec;
unsigned char t_min;
char i;
unsigned char lum;
unsigned char retval1;
unsigned char retval2;
unsigned char retval3;
unsigned char seg[9]={0x37, 0x06, 0x00, 0x37, 0x4f, 0x0e, 0x0e, 0x7e, 0x00};   // "HI HELLO"

#define LCD_RS LATB4_bit
#define LCD_EN LATB5_bit                                                       // data clocked out on falling edge

//Timer0 initialise 10ms interrupt (not very accurate)
void Interrupt_Init()
{

    T0CON0 = 0x80;                                                              // T0 on, 8 bit, 1:1 postscaler
    T0CON1 = 0x4a;                                                              // fosc/4, 1:1024 prescaler
    TMR0H = 0x9b;                                                               // adjust for 10ms interrupt
    TMR0L = 0x00;                                                               // not really relevant
    TMR0IE_bit = 1;                                                             // enable timer 0 interrupts
    
    INTCON = 0xc0;                                                              // GIE enabled, PIE enabled, Falling edge     
}
 
void interrupt ()
{
    if(TMR0IE && TMR0IF){
        count10ms ++;
        LATA0_bit = ~LATA0_bit;                                                 // should give 50Hz on RA0
        TMR0IF_bit = 0;                                                         // clear interrupt
    }
}

// write a single byte to SPI 1
unsigned char SPI_Write(unsigned char spi_byte){

    SSP2BUF = spi_byte;
    while(!BF2_bit);                                                            // wait for SPI to finish
    return SSP2BUF;    
}

// clear LCD screen
void LCD_Clear(void){
	LCD_Cmd(1);
}

// set LCD cursor position row can be 1 or 2, column can be 1 to 16
void LCD_Pos(unsigned char row, unsigned char col){
  unsigned char offset;
	
	offset = 0x7f + col;                                                        // start by assuming row 1 (default)
	if(row == 2){
		offset += 0x40;                                                         // adjust to 0xc0 + col-1 for row 2
	}
	if(row == 3){
		offset += 0x14;                                                         // adjust to 0x94 + col-1 for row 3
	}
	if(row == 4){
		offset += 0x54;                                                         // adjust to 0xd4 + col-1 for row 4
	}
    LCD_Cmd(offset);                                                            // first nibble
}

// set 4 bit data to LCD data lines
void LCD_Data4(unsigned char lcd_d){
    LATB0_bit = lcd_d;                                                          // bit 0
    LATB1_bit = lcd_d >> 1;                                                     // bit 1
    LATB2_bit = lcd_d >> 2;                                                     // bit 2
    LATB3_bit = lcd_d >> 3;                                                     // bit 3
}

// send 4 bit command
void LCD_Cmd4(char lcmd){
	LCD_RS = 0;                                                                 // select data register
	LCD_Data4(lcmd);
	LCD_EN  = 1;                                                                // rising edge has no effect
    Delay_ms(4);                                                                // minimum 39 us - but need 4ms for all commands to complete
    LCD_EN  = 0;                                                                // falling edge causes write
}

// send 8 bit command - requires two nibbles to be written as this is 4 bit mode
void LCD_Cmd(unsigned char lcmd){
	LCD_RS = 0;                                                                 // select data register
	LCD_Data4(lcmd >> 4);                                                       // high nibble
	LCD_EN  = 1;                                                                // rising edge has no effect
    Delay_ms(4);                                                                // minimum 39 us - but need 4ms for all commands to complete
    LCD_EN  = 0;                                                                // falling edge causes write
    Delay_ms(4);                                                                // minimum 39 us - but need 4ms for all commands to complete
	LCD_Data4(lcmd);                                                            // low nibble
	LCD_EN  = 1;                                                                // rising edge has no effect
    Delay_ms(4);                                                                // minimum 39 us - but need 4ms for all commands to complete
    LCD_EN  = 0;                                                                // falling edge causes write
}

// write a single byte of data to LCD - requires two nibbles to be written as this is 4 bit mode
void LCD_Write(unsigned char lcd_byte){

    LCD_RS = 1;                                                                 // select command register                              
    LCD_Data4((lcd_byte & 0xF0) >> 4);                                          // high nibble
	LCD_EN  = 1;                                                                // rising edge has no effect
    Delay_us(40);                                                               // minimum 37 us
    LCD_EN  = 0;                                                                // falling edge causes write
    LCD_Data4(lcd_byte & 0x0F);                                                 // low nibble
	LCD_EN  = 1;                                                                // rising edge has no effect
    Delay_us(40);                                                               // minimum 37 us
    LCD_EN  = 0;                                                                // falling edge causes write
}

// send null-terminated string to LCD
void LCD_Text(char *ltxt){
  int i;
  
	for(i = 0; ltxt[i] != 0; i++)
	   LCD_Write(ltxt[i]);
}

// initialise LCD to 4 bit mode
void LCD_Init(){
    TRISB5_bit = 0;                                                             // RB5  E is an output
    TRISC2_bit = 0;                                                             // RC2 back-light is an output
    LATC2_bit = 0;                                                              // RC2 back-light on
    TRISB &= 0xe0;                                                              // RB4 output for RS, RB 0,1,2,3 output for data lines

    LCD_Data4(0x00);
    Delay_ms(100);                                                              // minimum 40ms power-up time for LCD module
    LCD_Cmd4(0x03);                                                             // function set
	Delay_ms(5);                                                                // minimum 39 us
    LCD_Cmd4(0x03);                                                             // function set
	Delay_ms(11);                                                               // minimum 39 us
    LCD_Cmd(0x32);                                                              // function set
    LCD_Cmd(0x28);                                                              // display on
    LCD_Cmd(0x0C);
    LCD_Cmd(0x06);
    LCD_Clear();
    LCD_Pos(1,1);
}


// initialise PPS map as desired - be sure to set PPS1WAY = OFF in configuration settings
void PPS_Init(void){
    
    RC6PPS = 0x09;                                                              // UART 1 Tx RC6 output (options are PORT A and PORT C)
    RX1PPS = 0x17;                                                              // UART 1 Rx RC7 input  (options are PORT A and PORT C)
    RB6PPS = 0x0b;                                                              // UART 2 Tx RB6 output (options are PORT B and PORT D)
    RX2PPS = 0x0f;                                                              // UART 2 Rx RB7 input  (options are PORT B and PORT D)
    RX2PPS = 0x0f;                                                              // UART 2 Rx RB7 input  (options are PORT B and PORT D)
    RC3PPS = 0x0f;                                                              // RC3 I2C SCL
    RC4PPS = 0x10;                                                              // RC4 I2C SDA

    RD3PPS = 0x11;                                                              // RD3 SPI 2 SCK out
    SSP2CLKPPS = 0x1b;                                                          // RD3 SPI 2 SCK in
    SSP2DATPPS = 0x1a;                                                          // RD2 SPI 2 MISO
    RD5PPS = 0x12;                                                              // RD5 SPI 2 MOSI
}

// initialise SPI 2
void SPI2_Init(void){
    SSP2STAT = 0x40;                                                            // CKP=1 data change on falling clock
    SSP2CON1 = 0x22;                                                            // SPI enabled, Fosc/64
    SSP2CON3 = 0;
    SSP2ADD = 200;                                                              // bit rate
    Chip_Select = 1;
    Chip_Select_Direction = 0;
}

// initialise IO ports
void IO_Init(void){

    SLRCONA = 0;                                                                // fast IO
    SLRCONB = 0;                                                                // fast IO
    SLRCONC = 0;                                                                // fast IO
    SLRCOND = 0;                                                                // fast IO
    SLRCONE = 0;                                                                // fast IO
    LATA = 0;                                                                   // all low
    LATB = 0;                                                                   // all low
    LATC = 0;                                                                   // all low
    LATD = 0;                                                                   // all low
    LATE = 0;                                                                   // all low
    ANSELA = 0;                                                                 // all digital
    ANSELB = 0;                                                                 // all digital
    ANSELC = 0;                                                                 // all digital
    ANSELD = 0;                                                                 // all digital
    ANSELE = 0;                                                                 // all digital
    TRISA = 0;                                                                  // all output
    TRISB = 0x80;                                                               // RB7 UART2 input, rest output
    TRISC = 0x98;                                                               // RC7 UART1 input, RC3+4 I2C input, rest output
    TRISD = 0x04;                                                               // RD2 input SPI2 MISO, rest output
    TRISE = 0;                                                                  // all output    
}

// initialise UART
void UART_Init(void){
    
    RC1STA = 0x90;                                                              // Rx enable 8 bit
    TX1STA = 0x20;                                                              // Tx enable
    BAUD1CON = 0x08;                                                            // 16 bit BRG
    SP1BRG = 0x0022;                                                            // set baud rate - 00cf=19200, 0022=115200

    RC2STA = 0x90;                                                              // Rx enable 8 bit
    TX2STA = 0x20;                                                              // Tx enable
    BAUD2CON = 0x08;                                                            // 16 bit BRG
    SP2BRG = 0x00cf;                                                            // set baud rate - 00cf=19200
    Delay_ms(100);                                                              // UART settle time
}

// wait for character to be received from UART
unsigned char chin(void){
 
    while( ! RCIF_bit);                                                         // wait for character to be available
    return RC1REG;                                                              // read and return the character
}

// send character to UART
void putch(unsigned char uout_char){
    
    while( ! TXIF_bit);                                                         // wait for Tx ready
    TX1REG = uout_char;                                                         // send the character
}

// send null-terminated string to LCD
void printf(char *ltxt){
  int i;
  
	for(i = 0; ltxt[i] != 0; i++)
	   putch(ltxt[i]);
}

//--------------------- Reads time and date information from RTC (DS1307)
void Read_Time(char *sec, char *min, char *hr, char *week_day, char *day, char *mn, char *year) {

    I2C1_Start();
    I2C1_Wr(0xD0);                                                              // RTC address 0x38 shifted left, r/w cleared for write
    I2C1_Wr(0);                                                                 // start from register 0
    I2C1_Repeated_Start();
    I2C1_Wr(0xD1);                                                              // RTC address 0x38, shifted left, r/w set for read
    *sec = I2C1_Rd(1);                                                          // register 0
    *min = I2C1_Rd(1);                                                          // register 1
    *hr = I2C1_Rd(1);                                                           // register 2
    *week_day = I2C1_Rd(1);                                                     // register 3
    *day = I2C1_Rd(1);                                                          // register 4
    *mn = I2C1_Rd(1);                                                           // register 5
    *year = I2C1_Rd(0);                                                         // register 6
    I2C1_Stop();
}

//-------------------- Formats date and time
void Transform_Time(char  *sec, char *min, char *hr, char *week_day, char *day, char *mn, char *year) {
    *sec  =  ((*sec & 0x70) >> 4)*10 + (*sec & 0x0F);
    *min  =  ((*min & 0xF0) >> 4)*10 + (*min & 0x0F);
    *hr   =  ((*hr & 0x30) >> 4)*10 + (*hr & 0x0F);
    *week_day =(*week_day & 0x07);
    *day  =  ((*day & 0xF0) >> 4)*10 + (*day & 0x0F);
    *mn   =  ((*mn & 0x10) >> 4)*10 + (*mn & 0x0F);
    *year =  ((*year & 0xF0)>>4)*10+(*year & 0x0F);
}

//-------------------- Output values to UART
void Display_Time(char sec, char min, char hr, char week_day, char day, char mn, char year) {

    printf("\r");
    switch(week_day){
        case 1:
            txt = "Sun";
            break;
        case 2:
            txt = "Mon";
            break;
        case 3:
            txt = "Tue";
            break;
        case 4:
            txt = "Wed";
            break;
        case 5:
            txt = "Thu";
            break;
        case 6:
            txt = "Fri";
            break;
        case 7:
            txt = "Sat";
            break;
        default:
            txt = "Inv";
            break;
   }
   printf(txt);

   putch(' ');
   putch((day / 10) + 48);                                                      // Print tens digit of day variable
   putch((day % 10)   + 48);                                                    // Print ones digit of day variable
   putch('-');
   putch((mn / 10) + 48);
   putch((mn % 10) + 48);
   printf("-202");
   putch( year  + 48);                                                          // Print year

   putch(' ');
   putch((hr / 10)   + 48);
   putch((hr % 10)   + 48);
   putch(':');
   putch((min / 10) + 48);
   putch((min % 10) + 48);
   putch(':');
   putch((sec / 10) + 48);
   putch((sec % 10) + 48);
   if((sec > 59 ) || (min > 59 ) || (hr > 23 ) || (day > 31 ) || (mn > 12 )){
       printf("  * Invalid ! *"); 
       printf("\r\n  check 1307 RTC connections\r\n"); 
       printf("  check that supply is 5 Volts, not 3.3 Volts\r\n"); 
   }
}

// main program starts here
void main(void) {

    PPS_Init();                                                                 // map UART pins
    IO_Init();
    UART_Init();
    LCD_Init();
    LCD_Text("Mon7a 26-09-22  ");
    Interrupt_Init();
    
    I2C1_Init(100000);
    SPI2_Init();
    
    
    printf("\r\nMon7a 26 September 2022\r\n\n");

    while(1){
        linein(linebuff);                                                       // fetch a line of text
        newcmd = getparams(linebuff);                                           // read hex parameters
        switch(newcmd){                                                         // act upon command letter
            case '7':
                cmd7();
                break;

            case 'A':
                cmda();
                break;

            case 'D':
                cmdd();
                break;

            case 'F':
                cmdf();
                break;

            case 'L':
                cmdl();
                break;

            case 'R':
                cmdr();
                break;

            case 'T':
                cmdt();
                break;

            case 'W':
                cmdw();
                break;

            case 'Z':
                cmdz();
                break;

            case '?':
                printf("\r\n");
                printf("?                 List Commands\r\n");
                printf("7                 serial 7-seg test\r\n");
                printf("a dd dd dd        SPI write\r\n");
                printf("d mm hh w dd mm y write Date/time to 1307 RTC\r\n");
                printf("f dd              Fill with dd i2cEEPROM\r\n");
                printf("l                 LCD test\r\n");
                printf("r                 Read i2cEEPROM\r\n");
                printf("t                 read Time from 1307 RTC\r\n");
                printf("w aaa dd          Write i2cEEPROM\r\n");
                printf("z                 set fixed date/time to 1307 RTC\r\n");
                printf("\r\n");
                break;
            default:{
                printf("\r\ncommand not recognised\r\n");
                break;
            }
        }
    }
}

// Initialise I2C in master mode - clock frequency is ignored - 100KHz only
void I2C1_Init(const unsigned long clock){
  
    SSP1STAT = 0x80;                                                            // Slew rate control is disabled for Standard Speed mode (100 kHz and 1 MHz)
    SSP1CON1 = 0x28;                                                            // I2C Master mode, clock = FOSC/(4 * (SSPADD + 1))
    SSP1CON2 = 0x00;
    SSP1ADD = 49;                                                               // 100kHz clock @ 20MHz Fosc SSPADD = ( (Fosc/4) / BiteRate )-1
                                                                                // SSPADD = ( 20MHz / 100KHz ) - 1 = 49 //
}

// Send an I2C START
// Return 0 if all ok, 1 if bus collision
unsigned short I2C1_Start(void){
    BCL1IF_bit = 0;  //Clear 'Bus collision" flag
    SEN1_bit = 1;                                                               // initiate a START cycle
    while (SEN1_bit);                                                           // wait until it has been sent
    return BCL1IF_bit;                                                          // return value of BCLIF flag
}

// Send an I2C STOP
void I2C1_Stop(void){
    PEN1_bit = 1;                                                               // initiate a STOP cycle
    while (PEN1_bit);                                                           // wait until it has been sent
}

// Send an I2C REPEATED START
void I2C1_Repeated_Start(void){
    RSEN1_bit = 1;                                                              // initiate a REPEATED START cycle
    while (RSEN1_bit);                                                          // wait until it has been sent
}

// Receive one byte. ackflag=0 to send ACK, or 1 to send NAK in reply
// Send one byte. Return 0 if ACK received, or 1 if NAK received
unsigned short I2C1_Wr(unsigned short data_){
    SSP1BUF = (unsigned char)data_;
    asm ("nop");                                                                // <<<--- wait a little for R_W to be set
    while (R_W1_bit);                                                           // wait until byte sent and ACK/NAK received
    return ACKSTAT1_bit;
}

unsigned char I2C1_Rd(unsigned char ackflag){
    RCEN1_bit = 1;                                                              // initiate a RECEIVE cycle
    ACKDT1_bit = !(ackflag & 0x01);                                             // specify if we should send ACK or NAK after receiving
    while (RCEN1_bit);                                                          // wait until RECEIVE has completed
    ACKEN1_bit = 1;                                                             // initiate an ACK cycle
    while (ACKEN1_bit);                                                         // wait until it has completed
    return SSP1BUF;
}


//--------------- Writes data to I2C EEPROM - single location
void i2cEEPROM_WrSingle(unsigned int wAddr, unsigned char wData) {
  unsigned char hi_addr;                                                        // top two bits of address to bits 2,1

    wAddr &= 0x3ff;                                                             // force address to a valid address
    hi_addr = (wAddr >> 7) & 0x06;                                              // extract top two address bits to bits 2,1
    I2C1_Start();                                                               // issue I2C start signal
    I2C1_Wr(0xA0 | hi_addr);                                                    // send byte via I2C  (device address + W)
    I2C1_Wr(wAddr);                                                             // send byte (address of EEPROM location)
    I2C1_Wr(wData);                                                             // send data (data to be written)
    I2C1_Stop();                                                                // issue I2C stop signal
    Delay_ms(10);                                                               //  too lazy to work out how long to wait, so over-long wait
}

//--------------- Reads data from I2C EEPROM - single location (random)
unsigned char i2cEEPROM_RdSingle(unsigned int rAddr) {
  unsigned char result;
  unsigned char hi_addr;                                                        // top two bits of address to bits 2,1

    rAddr &= 0x3ff;                                                             // force address to a valid address
    hi_addr = (rAddr >> 7) & 0x06;                                              // extract top two address bits to bits 2,1
    I2C1_Start();                                                               // issue I2C start signal
    I2C1_Wr(0xA0 | hi_addr);                                                    // send byte via I2C  (device address + W)
    I2C1_Wr(rAddr);                                                             // send byte (data address)
    I2C1_Repeated_Start();                                                      // issue I2C signal repeated start
    I2C1_Wr(0xA1 | hi_addr);                                                    // send byte (device address + R)
    result = I2C1_Rd(0);                                                        // Read the data (NO acknowledge)
    I2C1_Stop();                                                                // issue I2C stop signal
    return result;
}

// display byte in hex
void PrintHex(unsigned char ihex) {
unsigned char hib,lob;

    hib = ihex & 0xF0;                                                          // high nibble
    hib = hib >> 4;
    hib = hib + '0';
    if (hib > '9') hib = hib + 7;
    lob = (ihex & 0x0F) + '0';                                                  // low nibble
    if (lob > '9') lob = lob+7;

    putch(hib);
    putch(lob);
}

// display byte in hex with trailing space
void PrintHexSp(unsigned char ihex) {
unsigned char hib,lob;

    hib = ihex & 0xF0;                                                          // high nibble
    hib = hib >> 4;
    hib = hib + '0';
    if (hib > '9') hib = hib + 7;
    lob = (ihex & 0x0F) + '0';                                                  // low nibble
    if (lob > '9') lob = lob + 7;

    putch(hib);
    putch(lob);
    putch(' ');
}

// display unsigned integer in hex
void PrintHexInt(unsigned int ihex) {
    PrintHex((ihex >> 8) & 0xff);
    PrintHex(ihex & 0xff);
}

// get parameters from string
char getparams(char* tempstring){
  char oldcmd;                                                                  // remember old command letter
  int  n;                                                                       // counter
  char tempchar;                                                                // temp store
  char tempchar2;                                                               // temp store
  unsigned int pointer1 = 0;                                                    // pointer within string
  unsigned int pointer2 = 0;                                                    // pointer within string

    oldcmd = cmd;                                                               // remember old value
    nparams = 0;                                                                // initialise
    pointer1 = 0;                                                               // initialise

    for ( n = 0 ; n < 8 ; n++){                                                 // count 0 to 7
        // skip leading spaces
        tempchar=1;                                                             // init
        do {
            tempchar = tempstring[pointer1++];
        } while (tempchar == 0x20);
        pointer1--;                                                             // leave pointer after param

        // count parameters
        if ((tempchar != 0) && (nparams < 8)){
            nparams++;
        }

        if (n == 0){                                                            // only for param 0
            tempchar=tempstring[pointer1];                                      // get only first letter
            if ((tempchar > 0x60) && (tempchar < 0x7b)) {
                tempchar -= 0x20;                                               // to upper case
            }
            cmd=tempchar;
        }

        tempchar=1;                                                             // initialise
        if (nparams != 0){                                                      // only for non-blank line
            // get all characters
            pointer2=0;                                                         // initialise
            do {
                tempchar = tempstring[pointer1++];                              // get char
                if ((tempchar > 0x60) && (tempchar < 0x7b)) {
                    tempchar -= 0x20;                                           // to upper case
                }
                param[n][pointer2++] = tempchar;                                // and store it
            } while ((tempchar > 0x20) && (tempchar < 0x7f) && (pointer2 < 20)); // text
            param[n][pointer2-1]=0;                                             // zero terminate param string
            if((tempchar == 0)||(n == 9)){                                      // no more params if end of line
                break;
            }
        }
    }

    // convert parameter strings to hex longwords
    for (n = 0; n < nparams ; n++){                                             // parms are 0 to 7
        tempchar2=1;                                                            // initialise
        pointer1=0;                                                             // initialise
        upar[n]=0;                                                              // initialise
        do {
            tempchar = param[n][pointer1++];
            // read one character
            if ( tempchar != 0 ){
                upar[n] = upar[n] * 0x10;                                       // next most signicant hex digit
            }
            tempchar2 = tempchar;                                               // remember original character
            if ((tempchar < 0x30) || (tempchar > 0x46)) {
                tempchar = 0x00;                                                // non-hex to zero
            }
            if ((tempchar > 0x39) && (tempchar < 0x41)) {
                tempchar = 0x00;                                                // non-hex to zero
            }
            if ((tempchar > 0x40) && (tempchar < 0x47)) {
                tempchar -= 0x37;                                               // to bin
            }
            if ((tempchar > 0x2f) && (tempchar < 0x3a)) {
                tempchar -= 0x30;                                               // to bin
            }
            upar[n] += tempchar;
        } while (tempchar2 != 0);
    }

    if (nparams == 0) {
        cmd = oldcmd;
    }
    return cmd;
}

// get a string from UART1.
// Input: Buffer pointer.
// Output: updated buffer.
void linein(char* pstring){
  char inChar = 0;

    while(inChar != '\r'){                                                      // keep reading until CR

        //UART1 read
        if (RC1IF_bit){                                                         // if a character is received, then process it
            inChar = chin();                                                    // get the character
            if(inChar != '\n'){                                                 // ignore new line completely
                putch(inChar);                                                  // echo the character
                if(inChar == '\r'){                                             // CR
                    putch('\n');                                                // send LF if CR received
                    *pstring ++= '\0';                                          // null terminate the received string
                }
                else {
                    if (inChar != 0x08 ){                                       // if not backspace
                        *pstring++ = inChar;                                    // add the new character to the receive string
                    }
                    if (inChar == 0x08 ){                                       // handle backspace (very crudely)
                        *--pstring = 0x00;                                      // move terminator back
                    }
                }
            }
        }
    }
}

// test for serial 7-seg display on PORT D
void cmd7(void){
    Chip_Select_Direction = 0;                                                  // Set RD0 pin as output

    max7219_init();                                                             // initialize  max7219

    for (i = 1; i <= 8; i++) {
        Chip_Select = 0;                                                        // select max7219
        SPI_Write(i);                                                           // send i to max7219 (digit place)
        SPI_Write(seg[8-i]);                                                    // send 9-i to max7219 (digit value)
        Chip_Select = 1;                                                        // deselect max7219
    }
}

// SPI test
void cmda(void){

    printf("RD3 CLK, RD2 MISO, RD5 MOSI, RD0 CS#\r\n");
    TRISD2_bit = 1;                                                            // output
    retval1 = upar[1] & 0xff;
    retval2 = upar[2] & 0xff;
    retval3 = upar[3] & 0xff;
    PrintHexSp(retval1);
    PrintHexSp(retval2);
    PrintHexSp(retval3);
    printf("SPI send\r\n");

    Chip_Select  = 0;                                                          // CS# asserted

    retval1 = SPI_Write(retval1);
    retval2 = SPI_Write(retval2);
    retval3 = SPI_Write(retval3);

    Chip_Select  = 1;                                                          // CS# un-asserted
    PrintHexSp(retval1);
    PrintHexSp(retval2);
    PrintHexSp(retval3);
    printf("received\r\n");
}

// write date to 1307 RTC
void cmdd(void){
    if(nparams < 2){                                                            // warn if wrong number of parameters, but allow anyway to default to old values
        printf("\r\nneed at least 1 parameter...\r\nd mm hh w dd mm y\r\n");
        printf("minute, hour, weekday 1=Sun, day, month, year 0-9\r\n\n");
    }
    else{
        I2C1_Start();                                                           // issue start signal
        I2C1_Wr(0xD0);                                                          // address DS1307  (0x68 shifted left by one)
        I2C1_Wr(0);                                                             // start from word at address (REG0)
        I2C1_Wr(0x80);                                                          // write $80 to REG0. (pause counter + 0 sec)
        I2C1_Wr(upar[1] & 0xff);                                                // write to minutes word to (REG1)
        if(nparams > 2){
            I2C1_Wr(upar[2] & 0xff);                                            // write to hours word (24-hours mode)(REG2)
            if(nparams > 3){
                I2C1_Wr(upar[3] & 0xff);                                        // write day (1 = Sunday) (REG3)
                if(nparams > 4){
                    I2C1_Wr(upar[4] & 0xff);                                    // write to date word (REG4)
                    if(nparams > 5){
                        I2C1_Wr(upar[5] & 0xff);                                // write to month word (REG5)
                        if(nparams > 6){
                            I2C1_Wr(upar[6] & 0xff);                            // write to year word (REG6)     
                        }
                    }
                }
            }
        }
        I2C1_Stop();                                                            // issue stop signal

        I2C1_Start();                                                           // issue start signal
        I2C1_Wr(0xD0);                                                          // address DS1307  (0x68 shifted left by one)
        I2C1_Wr(0);                                                             // start from word at address 0
        I2C1_Wr(0);                                                             // write 0 to REG0 (enable counting + 0 sec)
        I2C1_Stop();                                                            // issue stop signal
        printf("new date/time set\r\n\n");
    }
}
  
// fill with dd EEPROM Click
// f dd      write data dd (hex) to address aaa (hex)
void cmdf(void){

    EC_data = upar[1] & 0xff;                                                   // parameter 1 is byte value to fill with
    i2cEEPROM_WP = 0;                                                           // WP write enable when low
    printf("\r\nEEPROM Fill");

    if(nparams == 2){
        for(ee_addr = 0; ee_addr < 1024; ee_addr++){
            i2cEEPROM_WrSingle(ee_addr, EC_data);                               // write byte
            if((ee_addr & 0x1f) == 0){                                          // only print a dot every 32 bytes -
                printf(".");                                                    //    - to show that fill is still in progress
            }
        }
    }
    else{
        printf("\r\nsyntax error - need...\r\nf dd\r\n");
    }
    i2cEEPROM_WP = 1;                                                           // WP write protect when high
    printf("\r\ndone\r\n");
}

// simple LCD test
void cmdl(void){
    printf("2x16 LCD test\r\n\n");
    LCD_Init();                                                                 // initialise EP8 LCD
    LCD_Clear();
    LCD_Pos(1,1);                                                               // row 1 to 2, column 1 to 16
    LCD_Text("EasyPIC 7a Mon7a");
    LCD_Pos(2,1);                                                               // row 1 to 2, column 1 to 16
    LCD_Write(' ');                                                             // no purpose except to test function
    LCD_Text("Simple LCD test xxx");

    // rows 3 and 4 will not show on a 2x16 display
    LCD_Pos(3,1);                                                               // row 1 to 2, column 1 to 20
    LCD_Text("Line 3 of 4 x 20 LCD");
    LCD_Pos(4,1);                                                               // row 1 to 2, column 1 to 20
    LCD_Text("Line 4 of 4 x 20 LCD");
}

// read I2C EEPROM
void cmdr(void){
    i2cEEPROM_WP = 1;                                                           // WP write protect when high
    printf("\r\nEEPROM Contents...");
    ascii_string[16] = 0;                                                       // null terminate ASCII string
    ascii_string[0] = 0;                                                        // no ASCII string for first line

    for(EC_adr = 0; EC_adr < 1024; EC_adr++){                                   // 1k bytes in 24C08 I2C EEPROM, 256 bytes in 24C02 I2C EEPROM
        if(! (EC_adr & 0x0f)){                                                  // show address every 16th byte
            printf(ascii_string);                                               // print ASCII string at end of line
            printf("\r\n");
            PrintHexInt(EC_adr);                                                // print address byte as hex
            printf(" = ");
        }
        else{
            if(! (EC_adr & 0x03)){                                              // show '-' after every fourth byte
                printf("- ");
            }
        }
        EC_tmp = (EC_adr >> 8) & 0x03;                                          // get top 2 address bits
        EC_hdr = 0x50 + EC_tmp;                                                 // bare EEPROM i2c address + hi 2 bits EEPROM aggress
        EC_data = i2cEEPROM_RdSingle(EC_adr);                                   // read single byte (data address)
        PrintHexSp(EC_data);                                                    // print the data byte as hex
        if((EC_data > 31) && (EC_data < 128)){                                  // printable characters only
            ascii_string[EC_adr & 0x0f] = EC_data;                              // store ASCII for later print - limit pointer 0 to 0x0f
        }
        else{                                                                   // change non-printable character to dot
            ascii_string[EC_adr & 0x0f] = '.';                                  // store dot for later print - limit pointer 0 to 0x0f
        }
        Delay_ms(1);                                                            // slow down the display rate
    }
    printf(ascii_string);                                                       // print final ASCII string
    printf("\r\n");
}

// read time from 1307 I2C RTC
void cmdt(void){
    printf("time from 1307 RTC\r\n");
    Read_Time(&sec,&min1,&hr,&week_day,&day,&mn,&year);                         // read time from RTC(DS1307)
    t_sec = sec;
    t_min = min1;
    Transform_Time(&sec,&min1,&hr,&week_day,&day,&mn,&year);                    // format date and time     
    Display_Time(sec, min1, hr, week_day, day, mn, year);                       // prepare and display on LCD
    printf("\r\n");
}

// write to I2C EEPROM
// w aaa dd      write data dd (hex) to address aaa (hex)
void cmdw(void){

    EC_adr = upar[1];                                                           // parameter 1 is address 0 to 0x03ff
    EC_data = upar[2] & 0xff;                                                   // parameter 2 is data to write

    i2cEEPROM_WP = 0;                                                           // WP write enable when low
    printf("\r\nEEPROM Write...");

    Delay_ms(100);                                                              // no idea why I put this here :(

    if(nparams == 3){
        i2cEEPROM_WrSingle(EC_adr, EC_data);                                    // write byte
    }
    else{
        printf("syntax error - need...\r\nw aaa dd\r\n");
    }
    i2cEEPROM_WP = 1;                                                           // WP write protect when high
    printf("\r\n");
}

// set fixed date/time to 1307 RTC
void cmdz(void){
    I2C1_Start();                                                               // issue start signal
    I2C1_Wr(0xD0);                                                              // address DS1307  (0x68 shifted left by one)
    I2C1_Wr(0);                                                                 // start from word at address (REG0)
    I2C1_Wr(0x80);                                                              // write $80 to REG0. (pause counter + 0 sec)
    I2C1_Wr(0x00);                                                              // write to minutes word to (REG1)
    I2C1_Wr(0x23);                                                              // write to hours word (24-hours mode)(REG2)
    I2C1_Wr(0x07);                                                              // write day (1 = Sunday) (REG3)
    I2C1_Wr(0x24);                                                              // write to date word (REG4)
    I2C1_Wr(0x09);                                                              // write to month word (REG5)
    I2C1_Wr(0x02);                                                              // write to year word (REG6)
    I2C1_Stop();                                                                // issue stop signal

    I2C1_Start();                                                               // issue start signal
    I2C1_Wr(0xD0);                                                              // address DS1307  (0x68 shifted left by one)
    I2C1_Wr(0);                                                                 // start from word at address 0
    I2C1_Wr(0);                                                                 // write 0 to REG0 (enable counting + 0 sec)
    I2C1_Stop();                                                                // issue stop signal
    printf("1307 date/time reset\r\n");
}

void max7219_init() {
    Chip_Select = 0;       // SELECT MAX
    SPI_Write(0x09);       // raw mode for digit decoding
    SPI_Write(0x00);
    Chip_Select = 1;       // DESELECT MAX

    Chip_Select = 0;       // SELECT MAX
    SPI_Write(0x0A);
    SPI_Write(0x0b);       // Segment luminosity intensity
    Chip_Select = 1;       // DESELECT MAX

    Chip_Select = 0;       // SELECT MAX
    SPI_Write(0x0B);
    SPI_Write(0x07);      // Display refresh
    Chip_Select = 1;       // DESELECT MAX

    Chip_Select = 0;       // SELECT MAX
    SPI_Write(0x0C);
    SPI_Write(0x01);      // Turn on the display
    Chip_Select = 1;       // DESELECT MAX

    Chip_Select = 0;       // SELECT MAX
    SPI_Write(0x00);
    SPI_Write(0xFF);      // No test
    Chip_Select = 1;       // DESELECT MAX
    Delay_ms(100);
}


void set_luminosity(unsigned char value){
    Chip_Select = 0;               // SELECT MAX
    SPI_Write(0x0A);
    SPI_Write(value);               // Segment luminosity intensity
    Chip_Select = 1;               // DESELECT MAX
}
